@@ -7,12 +7,13 @@ from argus.callbacks.callback import (
     on_epoch_start,
     on_epoch_complete,
     on_iteration_start,
-    on_iteration_complete
+    on_iteration_complete,
+    on_catch_exception,
 )
 
 from argus.callbacks.checkpoints import (
     Checkpoint,
-    MonitorCheckpoint
+    MonitorCheckpoint,
 )
 
 from argus.callbacks.logging import LoggingToFile, LoggingToCSV
@@ -28,5 +29,5 @@ from argus.callbacks.lr_schedulers import (
     CyclicLR,
     CosineAnnealingWarmRestarts,
     MultiplicativeLR,
-    OneCycleLR
+    OneCycleLR,
 )
